# Qiuwen Baike bot / 求闻百科机器人

[Qiuwen Baike](https://www.qiuwenbaike.cn) bot. / [求闻百科](https://www.qiuwenbaike.cn)机器人。

## Features / 功能

- Comprehensive Cleanup / 综合治理
  - Cleaning up illegal references / 清理非法参考文献
  - Cleaning up unsupported HTML tags / 清理不支持的HTML标签
  - Cleaning up expired templates / 清理过期模板
  - Removing illegal flags of the Taiwan authorities / 清理台湾当局非法旗帜
  - Removing illegal era names of the Taiwan authorities / 清理台湾当局非法年号
  - Correcting terms related to Taiwan / 修正涉台用语
  - Correcting terms related to Hong Kong / 修正涉港用语
  - Correcting terms related to politics / 修正涉政用语
  - Correcting terms related to "Cultural Revolution" / 修正“文革”用语
- Marking redundant entries caused by differences between Simplified and Traditional Chinese / 标记简繁差异造成的重复条目

## Disclaimer / 免责声明

Qiuwen Baike® is a trademark or registered trademark of the operator of Qiuwen Baike website or its affiliated entities. This project uses the trademark legitimately based on Article 59 of the "Trademark Law of the People's Republic of China". When using it in the modified version of this project, one should observe the "Trademark Law". / 求闻百科®是求闻百科网站运营者或其关联实体的商标或注册商标，本项目基于《中华人民共和国商标法》第五十九条对该商标正当使用。在本项目的修改版本中使用时，应注意遵守《商标法》。
